#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-681cII1C4UOET5m9sENm4r
key:                  hw-hspec-hedgehog-0.1.1.1-681cII1C4UOET5m9sENm4r
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  6550f01c347d7b19f802c914bcd2ac0d
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-681cII1C4UOET5m9sENm4r
depends:
    HUnit-1.6.2.0-8Wn6BBwQEu19q9UZBWMuwr base-4.18.2.1
    call-stack-0.4.0-EHYATtZIWrX99WTqM3ptY4
    hedgehog-1.5-JAikhRfZUOWFYU2uDCz1vO
    hspec-2.11.4-51CvlZUKFvW7JJCx2o2BE transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

